<?php
require_once 'com/gmo_pg/client/input/EntryTranBankDirectInput.php';
require_once 'com/gmo_pg/client/input/ExecTranBankDirectInput.php';
/**
 * <b>口座直結決済登録・決済一括実行　入力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage input
 * @see inputPackageInfo.php
 * @author GMO PaymentGateway
 */
class EntryExecTranBankDirectInput {

	/**
	 * @var EntryTranBankDirectInput 口座直結決済登録入力パラメータ
	 */
	private $entryTranBankDirectInput;/* @var $entryTranInput EntryTranBankDirectInput */

	/**
	 * @var ExecTranBankDirectInput 口座直結決済実行入力パラメータ
	 */
	private $execTranBankDirectInput;/* @var $execTranInput ExecTranBankDirectInput */

	/**
	 * コンストラクタ
	 *
	 * @param array $params    入力パラメータ
	 */
	public function __construct($params = null) {
		$this->entryTranBankDirectInput = new EntryTranBankDirectInput($params);
		$this->execTranBankDirectInput = new ExecTranBankDirectInput($params);
	}

	/**
	 * 口座直結決済取引登録入力パラメータ取得
	 *
	 * @return EntryTranBankDirectInput 取引登録時パラメータ
	 */
	public function &getEntryTranBankDirectInput() {
		return $this->entryTranBankDirectInput;
	}

	/**
	 * 口座直結決済実行入力パラメータ取得
	 * @return ExecTranBankDirectInput 決済実行時パラメータ
	 */
	public function &getExecTranBankDirectInput() {
		return $this->execTranBankDirectInput;
	}

	/**
	 * ショップID取得
	 * @return string ショップID
	 */
	public function getShopID() {
		return $this->entryTranBankDirectInput->getShopID();

	}
	/**
	 * ショップパスワード取得
	 * @return string ショップパスワード
	 */
	public function getShopPass() {
		return $this->entryTranBankDirectInput->getShopPass();

	}
	/**
	 * サイトID取得
	 * @return string サイトID
	 */
	public function getSiteID() {
		return $this->entryTranBankDirectInput->getSiteID();
	}
	/**
	 * サイトパスワード取得
	 * @return string サイトパスワード
	 */
	public function getSitePass() {
		return $this->entryTranBankDirectInput->getSitePass();
	}
	/**
	 * 会員ID取得
	 * @return string 会員ID
	 */
	public function getMemberID() {
		return $this->entryTranBankDirectInput->getMemberID();
	}
	/**
	 * オーダーID取得
	 * @return string オーダーID
	 */
	public function getOrderID() {
		return $this->entryTranBankDirectInput->getOrderID();

	}
	/**
	 * 利用金額取得
	 * @return integer 利用金額
	 */
	public function getAmount() {
		return $this->entryTranBankDirectInput->getAmount();
	}
	/**
	 * 税送料取得
	 * @return integer 税送料
	 */
	public function getTax() {
		return $this->entryTranBankDirectInput->getTax();
	}
	/**
	 * 取引ID取得
	 * @return string 取引ID
	 */
	public function getAccessID() {
		return $this->execTranBankDirectInput->getAccessID();
	}
	/**
	 * 取引パスワード取得
	 * @return string 取引パスワード
	 */
	public function getAccessPass() {
		return $this->execTranBankDirectInput->getAccessPass();
	}
	/**
	 * 加盟店自由項目1取得
	 * @return string 加盟店自由項目1
	 */
	public function getClientField1() {
		return $this->execTranBankDirectInput->getClientField1();
	}
	/**
	 * 加盟店自由項目2取得
	 * @return string 加盟店自由項目2
	 */
	public function getClientField2() {
		return $this->execTranBankDirectInput->getClientField2();
	}
	/**
	 * 加盟店自由項目3取得
	 * @return string 加盟店自由項目3
	 */
	public function getClientField3() {
		return $this->execTranBankDirectInput->getClientField3();
	}
	/**
	 * 請求内容取得
	 * @return string 請求内容
	 */
	public function getRemarks() {
		return $this->execTranBankDirectInput->getRemarks();
	}

	/**
	 * 口座直結決済取引登録入力パラメータ設定
	 *
	 * @param EntryTranBankDirectInput entryTranBankDirectInput  取引登録入力パラメータ
	 */
	public function setEntryTranBankDirectInput(&$entryTranBankDirectInput) {
		$this->entryTranBankDirectInput = $entryTranBankDirectInput;
	}

	/**
	 * 口座直結決済実行入力パラメータ設定
	 *
	 * @param ExecTranBankDirectInput  execTranBankDirectInput   決済実行入力パラメータ
	 */
	public function setExecTranBankDirectInput(&$execTranBankDirectInput) {
		$this->execTranBankDirectInput = $execTranBankDirectInput;
	}

	/**
	 * ショップID設定
	 *
	 * @param string $shopID
	 */
	public function setShopID($shopID) {
		$this->entryTranBankDirectInput->setShopID($shopID);
		$this->execTranBankDirectInput->setShopID($shopID);

	}
	/**
	 * ショップパスワード設定
	 *
	 * @param string $shopPass
	 */
	public function setShopPass($shopPass) {
		$this->entryTranBankDirectInput->setShopPass($shopPass);
		$this->execTranBankDirectInput->setShopPass($shopPass);

	}
	/**
	 * サイトID設定
	 *
	 * @param string $siteID
	 */
	public function setSiteID($siteID) {
		$this->entryTranBankDirectInput->setSiteID($siteID);
	}
	/**
	 * サイトパスワード設定
	 *
	 * @param string $sitePass
	 */
	public function setSitePass($sitePass) {
		$this->entryTranBankDirectInput->setSitePass($sitePass);
	}
	/**
	 * 会員ID設定
	 *
	 * @param string $memberID
	 */
	public function setMemberID($memberID) {
		$this->entryTranBankDirectInput->setMemberID($memberID);
	}
	/**
	 * オーダーID設定
	 *
	 * @param string $orderID
	 */
	public function setOrderID($orderID) {
		$this->entryTranBankDirectInput->setOrderID($orderID);
		$this->execTranBankDirectInput->setOrderID($orderID);

	}
	/**
	 * 利用金額設定
	 *
	 * @param integer $amount
	 */
	public function setAmount($amount) {
		$this->entryTranBankDirectInput->setAmount($amount);
	}
	/**
	 * 税送料設定
	 *
	 * @param integer $tax
	 */
	public function setTax($tax) {
		$this->entryTranBankDirectInput->setTax($tax);
	}
	/**
	 * 取引ID設定
	 *
	 * @param string $accessID
	 */
	public function setAccessID($accessID) {
		$this->execTranBankDirectInput->setAccessID($accessID);
	}
	/**
	 * 取引パスワード設定
	 *
	 * @param string $accessPass
	 */
	public function setAccessPass($accessPass) {
		$this->execTranBankDirectInput->setAccessPass($accessPass);
	}
	/**
	 * 加盟店自由項目1設定
	 *
	 * @param string $clientField1
	 */
	public function setClientField1($clientField1) {
		$this->execTranBankDirectInput->setClientField1($clientField1);
	}
	/**
	 * 加盟店自由項目2設定
	 *
	 * @param string $clientField2
	 */
	public function setClientField2($clientField2) {
		$this->execTranBankDirectInput->setClientField2($clientField2);
	}
	/**
	 * 加盟店自由項目3設定
	 *
	 * @param string $clientField3
	 */
	public function setClientField3($clientField3) {
		$this->execTranBankDirectInput->setClientField3($clientField3);
	}
	/**
	 * 請求内容設定
	 *
	 * @param string $remarks
	 */
	public function setRemarks($remarks) {
		$this->execTranBankDirectInput->setRemarks($remarks);
	}

}
?>
