<?php
require_once 'com/gmo_pg/client/input/EntryTranDccInput.php';
require_once 'com/gmo_pg/client/input/ExecTranDccInput.php';
/**
 * <b>多通貨クレジット決済（DCC)登録・決済一括実行　入力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage input
 * @see inputPackageInfo.php
 * @author GMO PaymentGateway
 */
class EntryExecTranDccInput {

	/**
	 * @var EntryTranDccInput 多通貨クレジット決済（DCC)登録入力パラメータ
	 */
	private $entryTranDccInput;/* @var $entryTranDccInput EntryTranDccInput */

	/**
	 * @var ExecTranDccInput 多通貨クレジット決済（DCC)実行入力パラメータ
	 */
	private $execTranDccInput;/* @var $execTranDccInput ExecTranDccInput */

	/**
	 * コンストラクタ
	 *
	 * @param array $params    入力パラメータ
	 */
	public function __construct($params = null) {
		$this->entryTranDccInput = new EntryTranDccInput($params);
		$this->execTranDccInput = new ExecTranDccInput($params);
	}

	/**
	 * 多通貨クレジット決済（DCC)取引登録入力パラメータ取得
	 *
	 * @return EntryTranDccInput 取引登録時パラメータ
	 */
	public function &getEntryTranDccInput() {
		return $this->entryTranDccInput;
	}

	/**
	 * 多通貨クレジット決済（DCC)実行入力パラメータ取得
	 * @return ExecTranDccInput 決済実行時パラメータ
	 */
	public function &getExecTranDccInput() {
		return $this->execTranDccInput;
	}

	/**
	 * ショップID取得
	 * @return string ショップID
	 */
	public function getShopID() {
		return $this->entryTranDccInput->getShopID();

	}
	/**
	 * ショップパスワード取得
	 * @return string ショップパスワード
	 */
	public function getShopPass() {
		return $this->entryTranDccInput->getShopPass();

	}
	/**
	 * オーダーID取得
	 * @return string オーダーID
	 */
	public function getOrderID() {
		return $this->entryTranDccInput->getOrderID();

	}
	/**
	 * 支払通貨コード取得
	 * @return string 支払通貨コード
	 */
	public function getDccCurrency() {
		return $this->entryTranDccInput->getDccCurrency();
	}
	/**
	 * FX追跡番号取得
	 * @return string FX追跡番号
	 */
	public function getFtn() {
		return $this->entryTranDccInput->getFtn();
	}
	/**
	 * 商品コード取得
	 * @return string 商品コード
	 */
	public function getItemCode() {
		return $this->entryTranDccInput->getItemCode();
	}
	/**
	 * 利用料金取得
	 * @return integer 利用料金
	 */
	public function getAmount() {
		return $this->entryTranDccInput->getAmount();
	}
	/**
	 * 税送料取得
	 * @return integer 税送料
	 */
	public function getTax() {
		return $this->entryTranDccInput->getTax();
	}
	/**
	 * 3DS使用可否フラグ取得
	 * @return string 3DS使用可否フラグ
	 */
	public function getTdFlag() {
		return $this->entryTranDccInput->getTdFlag();
	}
	/**
	 * 3DS表示店舗名取得
	 * @return string 3DS表示店舗名
	 */
	public function getTdTenantName() {
		return $this->entryTranDccInput->getTdTenantName();
	}
	/**
	 * 取引ID取得
	 * @return string 取引ID
	 */
	public function getAccessID() {
		return $this->execTranDccInput->getAccessID();
	}
	/**
	 * 取引パスワード取得
	 * @return string 取引パスワード
	 */
	public function getAccessPass() {
		return $this->execTranDccInput->getAccessPass();
	}
	/**
	 * カード番号取得
	 * @return string カード番号
	 */
	public function getCardNo() {
		return $this->execTranDccInput->getCardNo();
	}
	/**
	 * 有効期限取得
	 * @return string 有効期限
	 */
	public function getExpire() {
		return $this->execTranDccInput->getExpire();
	}
	/**
	 * セキュリティコード取得
	 * @return string セキュリティコード
	 */
	public function getSecurityCode() {
		return $this->execTranDccInput->getSecurityCode();
	}
	/**
	 * トークン取得
	 * @return string トークン
	 */
	public function getToken() {
		return $this->execTranDccInput->getToken();
	}
	/**
	 * 加盟店自由項目1取得
	 * @return string 加盟店自由項目1
	 */
	public function getClientField1() {
		return $this->execTranDccInput->getClientField1();
	}
	/**
	 * 加盟店自由項目2取得
	 * @return string 加盟店自由項目2
	 */
	public function getClientField2() {
		return $this->execTranDccInput->getClientField2();
	}
	/**
	 * 加盟店自由項目3取得
	 * @return string 加盟店自由項目3
	 */
	public function getClientField3() {
		return $this->execTranDccInput->getClientField3();
	}
	/**
	 * 加盟店自由項目返却フラグ取得
	 * @return string 加盟店自由項目返却フラグ
	 */
	public function getClientFieldFlag() {
		return $this->execTranDccInput->getClientFieldFlag();
	}
	/**
	 * サイトID取得
	 * @return string サイトID
	 */
	public function getSiteID() {
		return $this->execTranDccInput->getSiteID();
	}
	/**
	 * サイトパスワード取得
	 * @return string サイトパスワード
	 */
	public function getSitePass() {
		return $this->execTranDccInput->getSitePass();
	}
	/**
	 * 会員ID取得
	 * @return string 会員ID
	 */
	public function getMemberID() {
		return $this->execTranDccInput->getMemberID();
	}
	/**
	 * モード取得
	 * @return string モード
	 */
	public function getSeqMode() {
		return $this->execTranDccInput->getSeqMode();
	}
	/**
	 * カード登録連番取得
	 * @return string カード登録連番
	 */
	public function getCardSeq() {
		return $this->execTranDccInput->getCardSeq();
	}
	/**
	 * カードパスワード取得
	 * @return string カードパスワード
	 */
	public function getCardPass() {
		return $this->execTranDccInput->getCardPass();
	}
	/**
	 * 3DS2.0非対応時取り扱い取得
	 * @return string 3DS2.0非対応時取り扱い
	 */
	public function getTds2Type() {
	    return $this->entryTranDccInput->getTds2Type();
	}
	/**
	 * 加盟店戻りURL取得
	 * @return string 加盟店戻りURL
	 */
	public function getRetUrl() {
	    return $this->execTranDccInput->getRetUrl();
	}
	
	/**
	 * コールバック方法取得
	 * @return string コールバック方法
	 */
	public function getCallbackType() {
	    return $this->execTranDccInput->getCallbackType();
	}
	
	
	/**
	 * カード会員最終更新日取得
	 * @return string カード会員最終更新日
	 */
	public function getTds2ChAccChange() {
	    return $this->execTranDccInput->getTds2ChAccChange();
	}
	
	/**
	 * カード会員作成日取得
	 * @return string カード会員作成日
	 */
	public function getTds2ChAccDate() {
	    return $this->execTranDccInput->getTds2ChAccDate();
	}
	
	/**
	 * カード会員パスワード変更日取得
	 * @return string カード会員パスワード変更日
	 */
	public function getTds2ChAccPwChange() {
	    return $this->execTranDccInput->getTds2ChAccPwChange();
	}
	
	/**
	 * 過去6ヶ月間の購入回数取得
	 * @return integer 過去6ヶ月間の購入回数
	 */
	public function getTds2NbPurchaseAccount() {
	    return $this->execTranDccInput->getTds2NbPurchaseAccount();
	}
	
	/**
	 * カード登録日取得
	 * @return string カード登録日
	 */
	public function getTds2PaymentAccAge() {
	    return $this->execTranDccInput->getTds2PaymentAccAge();
	}
	
	/**
	 * 過去24時間のカード追加の試行回数取得
	 * @return integer 過去24時間のカード追加の試行回数
	 */
	public function getTds2ProvisionAttemptsDay() {
	    return $this->execTranDccInput->getTds2ProvisionAttemptsDay();
	}
	
	/**
	 * 配送先住所の初回使用日取得
	 * @return string 配送先住所の初回使用日
	 */
	public function getTds2ShipAddressUsage() {
	    return $this->execTranDccInput->getTds2ShipAddressUsage();
	}
	
	/**
	 * カード会員名と配送先名の一致/不一致取得
	 * @return string カード会員名と配送先名の一致/不一致
	 */
	public function getTds2ShipNameInd() {
	    return $this->execTranDccInput->getTds2ShipNameInd();
	}
	
	/**
	 * カード会員の不審行為情報取得
	 * @return string カード会員の不審行為情報
	 */
	public function getTds2SuspiciousAccActivity() {
	    return $this->execTranDccInput->getTds2SuspiciousAccActivity();
	}
	
	/**
	 * 過去24時間の取引回数取得
	 * @return integer 過去24時間の取引回数
	 */
	public function getTds2TxnActivityDay() {
	    return $this->execTranDccInput->getTds2TxnActivityDay();
	}
	
	/**
	 * 前年の取引回数取得
	 * @return integer 前年の取引回数
	 */
	public function getTds2TxnActivityYear() {
	    return $this->execTranDccInput->getTds2TxnActivityYear();
	}
	
	/**
	 * ログイン証跡取得
	 * @return string ログイン証跡
	 */
	public function getTds2ThreeDSReqAuthData() {
	    return $this->execTranDccInput->getTds2ThreeDSReqAuthData();
	}
	
	/**
	 * ログイン方法取得
	 * @return string ログイン方法
	 */
	public function getTds2ThreeDSReqAuthMethod() {
	    return $this->execTranDccInput->getTds2ThreeDSReqAuthMethod();
	}
	
	/**
	 * ログイン日時取得
	 * @return string ログイン日時
	 */
	public function getTds2ThreeDSReqAuthTimestamp() {
	    return $this->execTranDccInput->getTds2ThreeDSReqAuthTimestamp();
	}
	
	/**
	 * 請求先住所と配送先住所の一致/不一致取得
	 * @return string 請求先住所と配送先住所の一致/不一致
	 */
	public function getTds2AddrMatch() {
	    return $this->execTranDccInput->getTds2AddrMatch();
	}
	
	/**
	 * 請求先住所の都市取得
	 * @return string 請求先住所の都市
	 */
	public function getTds2BillAddrCity() {
	    return $this->execTranDccInput->getTds2BillAddrCity();
	}
	
	/**
	 * 請求先住所の国番号取得
	 * @return string 請求先住所の国番号
	 */
	public function getTds2BillAddrCountry() {
	    return $this->execTranDccInput->getTds2BillAddrCountry();
	}
	
	/**
	 * 請求先住所の区域部分の１行目取得
	 * @return string 請求先住所の区域部分の１行目
	 */
	public function getTds2BillAddrLine1() {
	    return $this->execTranDccInput->getTds2BillAddrLine1();
	}
	
	/**
	 * 請求先住所の区域部分の２行目取得
	 * @return string 請求先住所の区域部分の２行目
	 */
	public function getTds2BillAddrLine2() {
	    return $this->execTranDccInput->getTds2BillAddrLine2();
	}
	
	/**
	 * 請求先住所の区域部分の３行目取得
	 * @return string 請求先住所の区域部分の３行目
	 */
	public function getTds2BillAddrLine3() {
	    return $this->execTranDccInput->getTds2BillAddrLine3();
	}
	
	/**
	 * 請求先住所の郵便番号取得
	 * @return string 請求先住所の郵便番号
	 */
	public function getTds2BillAddrPostCode() {
	    return $this->execTranDccInput->getTds2BillAddrPostCode();
	}
	
	/**
	 * 請求先住所の州または都道府県番号取得
	 * @return string 請求先住所の州または都道府県番号
	 */
	public function getTds2BillAddrState() {
	    return $this->execTranDccInput->getTds2BillAddrState();
	}
	
	/**
	 * カード会員のメールアドレス取得
	 * @return string カード会員のメールアドレス
	 */
	public function getTds2Email() {
	    return $this->execTranDccInput->getTds2Email();
	}
	
	/**
	 * 自宅電話の国コード取得
	 * @return string 自宅電話の国コード
	 */
	public function getTds2HomePhoneCC() {
	    return $this->execTranDccInput->getTds2HomePhoneCC();
	}
	
	/**
	 * 自宅電話番号取得
	 * @return string 自宅電話番号
	 */
	public function getTds2HomePhoneSubscriber() {
	    return $this->execTranDccInput->getTds2HomePhoneSubscriber();
	}
	
	/**
	 * 携帯電話の国コード取得
	 * @return string 携帯電話の国コード
	 */
	public function getTds2MobilePhoneCC() {
	    return $this->execTranDccInput->getTds2MobilePhoneCC();
	}
	
	/**
	 * 携帯電話番号取得
	 * @return string 携帯電話番号
	 */
	public function getTds2MobilePhoneSubscriber() {
	    return $this->execTranDccInput->getTds2MobilePhoneSubscriber();
	}
	
	/**
	 * 職場電話の国コード取得
	 * @return string 職場電話の国コード
	 */
	public function getTds2WorkPhoneCC() {
	    return $this->execTranDccInput->getTds2WorkPhoneCC();
	}
	
	/**
	 * 職場電話番号取得
	 * @return string 職場電話番号
	 */
	public function getTds2WorkPhoneSubscriber() {
	    return $this->execTranDccInput->getTds2WorkPhoneSubscriber();
	}
	
	/**
	 * 配送先住所の都市取得
	 * @return string 配送先住所の都市
	 */
	public function getTds2ShipAddrCity() {
	    return $this->execTranDccInput->getTds2ShipAddrCity();
	}
	
	/**
	 * 配送先住所の国番号取得
	 * @return string 配送先住所の国番号
	 */
	public function getTds2ShipAddrCountry() {
	    return $this->execTranDccInput->getTds2ShipAddrCountry();
	}
	
	/**
	 * 配送先住所の区域部分の１行目取得
	 * @return string 配送先住所の区域部分の１行目
	 */
	public function getTds2ShipAddrLine1() {
	    return $this->execTranDccInput->getTds2ShipAddrLine1();
	}
	
	/**
	 * 配送先住所の区域部分の２行目取得
	 * @return string 配送先住所の区域部分の２行目
	 */
	public function getTds2ShipAddrLine2() {
	    return $this->execTranDccInput->getTds2ShipAddrLine2();
	}
	
	/**
	 * 配送先住所の区域部分の３行目取得
	 * @return string 配送先住所の区域部分の３行目
	 */
	public function getTds2ShipAddrLine3() {
	    return $this->execTranDccInput->getTds2ShipAddrLine3();
	}
	
	/**
	 * 配送先住所の郵便番号取得
	 * @return string 配送先住所の郵便番号
	 */
	public function getTds2ShipAddrPostCode() {
	    return $this->execTranDccInput->getTds2ShipAddrPostCode();
	}
	
	/**
	 * 配送先住所の州または都道府県番号取得
	 * @return string 配送先住所の州または都道府県番号
	 */
	public function getTds2ShipAddrState() {
	    return $this->execTranDccInput->getTds2ShipAddrState();
	}
	
	/**
	 * 納品先電子メールアドレス取得
	 * @return string 納品先電子メールアドレス
	 */
	public function getTds2DeliveryEmailAddress() {
	    return $this->execTranDccInput->getTds2DeliveryEmailAddress();
	}
	
	/**
	 * 商品納品時間枠取得
	 * @return string 商品納品時間枠
	 */
	public function getTds2DeliveryTimeframe() {
	    return $this->execTranDccInput->getTds2DeliveryTimeframe();
	}
	
	/**
	 * プリペイドカードまたはギフトカードの総購入金額取得
	 * @return string プリペイドカードまたはギフトカードの総購入金額
	 */
	public function getTds2GiftCardAmount() {
	    return $this->execTranDccInput->getTds2GiftCardAmount();
	}
	
	/**
	 * 購入されたプリペイドカードまたはギフトカード の総数取得
	 * @return integer 購入されたプリペイドカードまたはギフトカード の総数
	 */
	public function getTds2GiftCardCount() {
	    return $this->execTranDccInput->getTds2GiftCardCount();
	}
	
	/**
	 * 購入されたプリペイドカードまたはギフトカードの通貨コード取得
	 * @return string 購入されたプリペイドカードまたはギフトカードの通貨コード
	 */
	public function getTds2GiftCardCurr() {
	    return $this->execTranDccInput->getTds2GiftCardCurr();
	}
	
	/**
	 * 商品の発売予定日取得
	 * @return string 商品の発売予定日
	 */
	public function getTds2PreOrderDate() {
	    return $this->execTranDccInput->getTds2PreOrderDate();
	}
	
	/**
	 * 商品の販売時期情報取得
	 * @return string 商品の販売時期情報
	 */
	public function getTds2PreOrderPurchaseInd() {
	    return $this->execTranDccInput->getTds2PreOrderPurchaseInd();
	}
	
	/**
	 * 商品の注文情報取得
	 * @return string 商品の注文情報
	 */
	public function getTds2ReorderItemsInd() {
	    return $this->execTranDccInput->getTds2ReorderItemsInd();
	}
	
	/**
	 * 取引の配送方法取得
	 * @return string 取引の配送方法
	 */
	public function getTds2ShipInd() {
	    return $this->execTranDccInput->getTds2ShipInd();
	}

	/**
	 * 多通貨クレジット決済（DCC)取引登録入力パラメータ設定
	 *
	 * @param EntryTranDccInput entryTranDccInput  取引登録入力パラメータ
	 */
	public function setEntryTranDccInput(&$entryTranDccInput) {
		$this->entryTranDccInput = $entryTranDccInput;
	}

	/**
	 * 多通貨クレジット決済（DCC)実行入力パラメータ設定
	 *
	 * @param ExecTranDccInput  execTranDccInput   決済実行入力パラメータ
	 */
	public function setExecTranDccInput(&$execTranDccInput) {
		$this->execTranDccInput = $execTranDccInput;
	}

	/**
	 * ショップID設定
	 *
	 * @param string $shopID
	 */
	public function setShopID($shopID) {
		$this->entryTranDccInput->setShopID($shopID);
		$this->execTranDccInput->setShopID($shopID);

	}
	/**
	 * ショップパスワード設定
	 *
	 * @param string $shopPass
	 */
	public function setShopPass($shopPass) {
		$this->entryTranDccInput->setShopPass($shopPass);
		$this->execTranDccInput->setShopPass($shopPass);

	}
	/**
	 * オーダーID設定
	 *
	 * @param string $orderID
	 */
	public function setOrderID($orderID) {
		$this->entryTranDccInput->setOrderID($orderID);
		$this->execTranDccInput->setOrderID($orderID);

	}
	/**
	 * 支払通貨コード設定
	 *
	 * @param string $dccCurrency
	 */
	public function setDccCurrency($dccCurrency) {
		$this->entryTranDccInput->setDccCurrency($dccCurrency);
	}
	/**
	 * FX追跡番号設定
	 *
	 * @param string $ftn
	 */
	public function setFtn($ftn) {
		$this->entryTranDccInput->setFtn($ftn);
	}
	/**
	 * 商品コード設定
	 *
	 * @param string $itemCode
	 */
	public function setItemCode($itemCode) {
		$this->entryTranDccInput->setItemCode($itemCode);
	}
	/**
	 * 利用料金設定
	 *
	 * @param integer $amount
	 */
	public function setAmount($amount) {
		$this->entryTranDccInput->setAmount($amount);
	}
	/**
	 * 税送料設定
	 *
	 * @param integer $tax
	 */
	public function setTax($tax) {
		$this->entryTranDccInput->setTax($tax);
	}
	/**
	 * 3DS使用可否フラグ設定
	 *
	 * @param string $tdFlag
	 */
	public function setTdFlag($tdFlag) {
		$this->entryTranDccInput->setTdFlag($tdFlag);
	}
	/**
	 * 3DS表示店舗名設定
	 *
	 * @param string $tdTenantName
	 */
	public function setTdTenantName($tdTenantName) {
		$this->entryTranDccInput->setTdTenantName($tdTenantName);
	}
	/**
	 * 取引ID設定
	 *
	 * @param string $accessID
	 */
	public function setAccessID($accessID) {
		$this->execTranDccInput->setAccessID($accessID);
	}
	/**
	 * 取引パスワード設定
	 *
	 * @param string $accessPass
	 */
	public function setAccessPass($accessPass) {
		$this->execTranDccInput->setAccessPass($accessPass);
	}
	/**
	 * カード番号設定
	 *
	 * @param string $cardNo
	 */
	public function setCardNo($cardNo) {
		$this->execTranDccInput->setCardNo($cardNo);
	}
	/**
	 * 有効期限設定
	 *
	 * @param string $expire
	 */
	public function setExpire($expire) {
		$this->execTranDccInput->setExpire($expire);
	}
	/**
	 * セキュリティコード設定
	 *
	 * @param string $securityCode
	 */
	public function setSecurityCode($securityCode) {
		$this->execTranDccInput->setSecurityCode($securityCode);
	}
	/**
	 * トークン設定
	 *
	 * @param string $token
	 */
	public function setToken($token) {
		$this->execTranDccInput->setToken($token);
	}
	/**
	 * 加盟店自由項目1設定
	 *
	 * @param string $clientField1
	 */
	public function setClientField1($clientField1) {
		$this->execTranDccInput->setClientField1($clientField1);
	}
	/**
	 * 加盟店自由項目2設定
	 *
	 * @param string $clientField2
	 */
	public function setClientField2($clientField2) {
		$this->execTranDccInput->setClientField2($clientField2);
	}
	/**
	 * 加盟店自由項目3設定
	 *
	 * @param string $clientField3
	 */
	public function setClientField3($clientField3) {
		$this->execTranDccInput->setClientField3($clientField3);
	}
	/**
	 * 加盟店自由項目返却フラグ設定
	 *
	 * @param string $clientFieldFlag
	 */
	public function setClientFieldFlag($clientFieldFlag) {
		$this->execTranDccInput->setClientFieldFlag($clientFieldFlag);
	}
	/**
	 * サイトID設定
	 *
	 * @param string $siteID
	 */
	public function setSiteID($siteID) {
		$this->execTranDccInput->setSiteID($siteID);
	}
	/**
	 * サイトパスワード設定
	 *
	 * @param string $sitePass
	 */
	public function setSitePass($sitePass) {
		$this->execTranDccInput->setSitePass($sitePass);
	}
	/**
	 * 会員ID設定
	 *
	 * @param string $memberID
	 */
	public function setMemberID($memberID) {
		$this->execTranDccInput->setMemberID($memberID);
	}
	/**
	 * モード設定
	 *
	 * @param string $seqMode
	 */
	public function setSeqMode($seqMode) {
		$this->execTranDccInput->setSeqMode($seqMode);
	}
	/**
	 * カード登録連番設定
	 *
	 * @param string $cardSeq
	 */
	public function setCardSeq($cardSeq) {
		$this->execTranDccInput->setCardSeq($cardSeq);
	}
	/**
	 * カードパスワード設定
	 *
	 * @param string $cardPass
	 */
	public function setCardPass($cardPass) {
		$this->execTranDccInput->setCardPass($cardPass);
	}
	/**
	 * 3DS2.0非対応時取り扱い
	 *
	 * @param string $tds2Type
	 */
	public function setTds2Type($tds2Type) {
	    $this->entryTranDccInput->setTds2Type($tds2Type);
	}
	/**
	 * 加盟店戻りURL設定
	 *
	 * @param string $retUrl 加盟店戻りURL
	 */
	public function setRetUrl($retUrl) {
	    $this->execTranDccInput->setRetUrl($retUrl);
	}
	
	/**
	 * コールバック方法設定
	 *
	 * @param string $callbackType コールバック方法
	 */
	public function setCallbackType($callbackType) {
	    $this->execTranDccInput->setCallbackType($callbackType);
	}
	
	/**
	 * カード会員最終更新日設定
	 *
	 * @param string $tds2ChAccChange
	 */
	public function setTds2ChAccChange($tds2ChAccChange) {
	    $this->execTranDccInput->setTds2ChAccChange($tds2ChAccChange);
	}
	
	/**
	 * カード会員作成日設定
	 *
	 * @param string $tds2ChAccDate
	 */
	public function setTds2ChAccDate($tds2ChAccDate) {
	    $this->execTranDccInput->setTds2ChAccDate($tds2ChAccDate);
	}
	
	/**
	 * カード会員パスワード変更日設定
	 *
	 * @param string $tds2ChAccPwChange
	 */
	public function setTds2ChAccPwChange($tds2ChAccPwChange) {
	    $this->execTranDccInput->setTds2ChAccPwChange($tds2ChAccPwChange);
	}
	
	/**
	 * 過去6ヶ月間の購入回数設定
	 *
	 * @param integer $tds2NbPurchaseAccount
	 */
	public function setTds2NbPurchaseAccount($tds2NbPurchaseAccount) {
	    $this->execTranDccInput->setTds2NbPurchaseAccount($tds2NbPurchaseAccount);
	}
	
	/**
	 * カード登録日設定
	 *
	 * @param string $tds2PaymentAccAge
	 */
	public function setTds2PaymentAccAge($tds2PaymentAccAge) {
	    $this->execTranDccInput->setTds2PaymentAccAge($tds2PaymentAccAge);
	}
	
	/**
	 * 過去24時間のカード追加の試行回数設定
	 *
	 * @param integer $tds2ProvisionAttemptsDay
	 */
	public function setTds2ProvisionAttemptsDay($tds2ProvisionAttemptsDay) {
	    $this->execTranDccInput->setTds2ProvisionAttemptsDay($tds2ProvisionAttemptsDay);
	}
	
	/**
	 * 配送先住所の初回使用日設定
	 *
	 * @param string $tds2ShipAddressUsage
	 */
	public function setTds2ShipAddressUsage($tds2ShipAddressUsage) {
	    $this->execTranDccInput->setTds2ShipAddressUsage($tds2ShipAddressUsage);
	}
	
	/**
	 * カード会員名と配送先名の一致/不一致設定
	 *
	 * @param string $tds2ShipNameInd
	 */
	public function setTds2ShipNameInd($tds2ShipNameInd) {
	    $this->execTranDccInput->setTds2ShipNameInd($tds2ShipNameInd);
	}
	
	/**
	 * カード会員の不審行為情報設定
	 *
	 * @param string $tds2SuspiciousAccActivity
	 */
	public function setTds2SuspiciousAccActivity($tds2SuspiciousAccActivity) {
	    $this->execTranDccInput->setTds2SuspiciousAccActivity($tds2SuspiciousAccActivity);
	}
	
	/**
	 * 過去24時間の取引回数設定
	 *
	 * @param integer $tds2TxnActivityDay
	 */
	public function setTds2TxnActivityDay($tds2TxnActivityDay) {
	    $this->execTranDccInput->setTds2TxnActivityDay($tds2TxnActivityDay);
	}
	
	/**
	 * 前年の取引回数設定
	 *
	 * @param integer $tds2TxnActivityYear
	 */
	public function setTds2TxnActivityYear($tds2TxnActivityYear) {
	    $this->execTranDccInput->setTds2TxnActivityYear($tds2TxnActivityYear);
	}
	
	/**
	 * ログイン証跡設定
	 *
	 * @param string $tds2ThreeDSReqAuthData
	 */
	public function setTds2ThreeDSReqAuthData($tds2ThreeDSReqAuthData) {
	    $this->execTranDccInput->setTds2ThreeDSReqAuthData($tds2ThreeDSReqAuthData);
	}
	
	/**
	 * ログイン方法設定
	 *
	 * @param string $tds2ThreeDSReqAuthMethod
	 */
	public function setTds2ThreeDSReqAuthMethod($tds2ThreeDSReqAuthMethod) {
	    $this->execTranDccInput->setTds2ThreeDSReqAuthMethod($tds2ThreeDSReqAuthMethod);
	}
	
	/**
	 * ログイン日時設定
	 *
	 * @param string $tds2ThreeDSReqAuthTimestamp
	 */
	public function setTds2ThreeDSReqAuthTimestamp($tds2ThreeDSReqAuthTimestamp) {
	    $this->execTranDccInput->setTds2ThreeDSReqAuthTimestamp($tds2ThreeDSReqAuthTimestamp);
	}
	
	/**
	 * 請求先住所と配送先住所の一致/不一致設定
	 *
	 * @param string $tds2AddrMatch
	 */
	public function setTds2AddrMatch($tds2AddrMatch) {
	    $this->execTranDccInput->setTds2AddrMatch($tds2AddrMatch);
	}
	
	/**
	 * 請求先住所の都市設定
	 *
	 * @param string $tds2BillAddrCity
	 */
	public function setTds2BillAddrCity($tds2BillAddrCity) {
	    $this->execTranDccInput->setTds2BillAddrCity($tds2BillAddrCity);
	}
	
	/**
	 * 請求先住所の国番号設定
	 *
	 * @param string $tds2BillAddrCountry
	 */
	public function setTds2BillAddrCountry($tds2BillAddrCountry) {
	    $this->execTranDccInput->setTds2BillAddrCountry($tds2BillAddrCountry);
	}
	
	/**
	 * 請求先住所の区域部分の１行目設定
	 *
	 * @param string $tds2BillAddrLine1
	 */
	public function setTds2BillAddrLine1($tds2BillAddrLine1) {
	    $this->execTranDccInput->setTds2BillAddrLine1($tds2BillAddrLine1);
	}
	
	/**
	 * 請求先住所の区域部分の２行目設定
	 *
	 * @param string $tds2BillAddrLine2
	 */
	public function setTds2BillAddrLine2($tds2BillAddrLine2) {
	    $this->execTranDccInput->setTds2BillAddrLine2($tds2BillAddrLine2);
	}
	
	/**
	 * 請求先住所の区域部分の３行目設定
	 *
	 * @param string $tds2BillAddrLine3
	 */
	public function setTds2BillAddrLine3($tds2BillAddrLine3) {
	    $this->execTranDccInput->setTds2BillAddrLine3($tds2BillAddrLine3);
	}
	
	/**
	 * 請求先住所の郵便番号設定
	 *
	 * @param string $tds2BillAddrPostCode
	 */
	public function setTds2BillAddrPostCode($tds2BillAddrPostCode) {
	    $this->execTranDccInput->setTds2BillAddrPostCode($tds2BillAddrPostCode);
	}
	
	/**
	 * 請求先住所の州または都道府県番号設定
	 *
	 * @param string $tds2BillAddrState
	 */
	public function setTds2BillAddrState($tds2BillAddrState) {
	    $this->execTranDccInput->setTds2BillAddrState($tds2BillAddrState);
	}
	
	/**
	 * カード会員のメールアドレス設定
	 *
	 * @param string $tds2Email
	 */
	public function setTds2Email($tds2Email) {
	    $this->execTranDccInput->setTds2Email($tds2Email);
	}
	
	/**
	 * 自宅電話の国コード設定
	 *
	 * @param string $tds2HomePhoneCC
	 */
	public function setTds2HomePhoneCC($tds2HomePhoneCC) {
	    $this->execTranDccInput->setTds2HomePhoneCC($tds2HomePhoneCC);
	}
	
	/**
	 * 自宅電話番号設定
	 *
	 * @param string $tds2HomePhoneSubscriber
	 */
	public function setTds2HomePhoneSubscriber($tds2HomePhoneSubscriber) {
	    $this->execTranDccInput->setTds2HomePhoneSubscriber($tds2HomePhoneSubscriber);
	}
	
	/**
	 * 携帯電話の国コード設定
	 *
	 * @param string $tds2MobilePhoneCC
	 */
	public function setTds2MobilePhoneCC($tds2MobilePhoneCC) {
	    $this->execTranDccInput->setTds2MobilePhoneCC($tds2MobilePhoneCC);
	}
	
	/**
	 * 携帯電話番号設定
	 *
	 * @param string $tds2MobilePhoneSubscriber
	 */
	public function setTds2MobilePhoneSubscriber($tds2MobilePhoneSubscriber) {
	    $this->execTranDccInput->setTds2MobilePhoneSubscriber($tds2MobilePhoneSubscriber);
	}
	
	/**
	 * 職場電話の国コード設定
	 *
	 * @param string $tds2WorkPhoneCC
	 */
	public function setTds2WorkPhoneCC($tds2WorkPhoneCC) {
	    $this->execTranDccInput->setTds2WorkPhoneCC($tds2WorkPhoneCC);
	}
	
	/**
	 * 職場電話番号設定
	 *
	 * @param string $tds2WorkPhoneSubscriber
	 */
	public function setTds2WorkPhoneSubscriber($tds2WorkPhoneSubscriber) {
	    $this->execTranDccInput->setTds2WorkPhoneSubscriber($tds2WorkPhoneSubscriber);
	}
	
	/**
	 * 配送先住所の都市設定
	 *
	 * @param string $tds2ShipAddrCity
	 */
	public function setTds2ShipAddrCity($tds2ShipAddrCity) {
	    $this->execTranDccInput->setTds2ShipAddrCity($tds2ShipAddrCity);
	}
	
	/**
	 * 配送先住所の国番号設定
	 *
	 * @param string $tds2ShipAddrCountry
	 */
	public function setTds2ShipAddrCountry($tds2ShipAddrCountry) {
	    $this->execTranDccInput->setTds2ShipAddrCountry($tds2ShipAddrCountry);
	}
	
	/**
	 * 配送先住所の区域部分の１行目設定
	 *
	 * @param string $tds2ShipAddrLine1
	 */
	public function setTds2ShipAddrLine1($tds2ShipAddrLine1) {
	    $this->execTranDccInput->setTds2ShipAddrLine1($tds2ShipAddrLine1);
	}
	
	/**
	 * 配送先住所の区域部分の２行目設定
	 *
	 * @param string $tds2ShipAddrLine2
	 */
	public function setTds2ShipAddrLine2($tds2ShipAddrLine2) {
	    $this->execTranDccInput->setTds2ShipAddrLine2($tds2ShipAddrLine2);
	}
	
	/**
	 * 配送先住所の区域部分の３行目設定
	 *
	 * @param string $tds2ShipAddrLine3
	 */
	public function setTds2ShipAddrLine3($tds2ShipAddrLine3) {
	    $this->execTranDccInput->setTds2ShipAddrLine3($tds2ShipAddrLine3);
	}
	
	/**
	 * 配送先住所の郵便番号設定
	 *
	 * @param string $tds2ShipAddrPostCode
	 */
	public function setTds2ShipAddrPostCode($tds2ShipAddrPostCode) {
	    $this->execTranDccInput->setTds2ShipAddrPostCode($tds2ShipAddrPostCode);
	}
	
	/**
	 * 配送先住所の州または都道府県番号設定
	 *
	 * @param string $tds2ShipAddrState
	 */
	public function setTds2ShipAddrState($tds2ShipAddrState) {
	    $this->execTranDccInput->setTds2ShipAddrState($tds2ShipAddrState);
	}
	
	/**
	 * 納品先電子メールアドレス設定
	 *
	 * @param string $tds2DeliveryEmailAddress
	 */
	public function setTds2DeliveryEmailAddress($tds2DeliveryEmailAddress) {
	    $this->execTranDccInput->setTds2DeliveryEmailAddress($tds2DeliveryEmailAddress);
	}
	
	/**
	 * 商品納品時間枠設定
	 *
	 * @param string $tds2DeliveryTimeframe
	 */
	public function setTds2DeliveryTimeframe($tds2DeliveryTimeframe) {
	    $this->execTranDccInput->setTds2DeliveryTimeframe($tds2DeliveryTimeframe);
	}
	
	/**
	 * プリペイドカードまたはギフトカードの総購入金額設定
	 *
	 * @param string $tds2GiftCardAmount
	 */
	public function setTds2GiftCardAmount($tds2GiftCardAmount) {
	    $this->execTranDccInput->setTds2GiftCardAmount($tds2GiftCardAmount);
	}
	
	/**
	 * 購入されたプリペイドカードまたはギフトカード の総数設定
	 *
	 * @param integer $tds2GiftCardCount
	 */
	public function setTds2GiftCardCount($tds2GiftCardCount) {
	    $this->execTranDccInput->setTds2GiftCardCount($tds2GiftCardCount);
	}
	
	/**
	 * 購入されたプリペイドカードまたはギフトカードの通貨コード設定
	 *
	 * @param string $tds2GiftCardCurr
	 */
	public function setTds2GiftCardCurr($tds2GiftCardCurr) {
	    $this->execTranDccInput->setTds2GiftCardCurr($tds2GiftCardCurr);
	}
	
	/**
	 * 商品の発売予定日設定
	 *
	 * @param string $tds2PreOrderDate
	 */
	public function setTds2PreOrderDate($tds2PreOrderDate) {
	    $this->execTranDccInput->setTds2PreOrderDate($tds2PreOrderDate);
	}
	
	/**
	 * 商品の販売時期情報設定
	 *
	 * @param string $tds2PreOrderPurchaseInd
	 */
	public function setTds2PreOrderPurchaseInd($tds2PreOrderPurchaseInd) {
	    $this->execTranDccInput->setTds2PreOrderPurchaseInd($tds2PreOrderPurchaseInd);
	}
	
	/**
	 * 商品の注文情報設定
	 *
	 * @param string $tds2ReorderItemsInd
	 */
	public function setTds2ReorderItemsInd($tds2ReorderItemsInd) {
	    $this->execTranDccInput->setTds2ReorderItemsInd($tds2ReorderItemsInd);
	}
	
	/**
	 * 取引の配送方法設定
	 *
	 * @param string $tds2ShipInd
	 */
	public function setTds2ShipInd($tds2ShipInd) {
	    $this->execTranDccInput->setTds2ShipInd($tds2ShipInd);
	}

}
?>
