<?php
require_once ('com/gmo_pg/client/input/BaseInput.php');

/**
 * <b>Webmoney決済実行　入力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage input
 * @see inputPackageInfo.php
 * @author GMO PaymentGateway
 * @version 1.0
 * @created 12-24-2009 00:00:00
 */
class ExecTranWebmoneyInput extends BaseInput {

	/**
	 * @var string GMO-PGが発行する、PGマルチペイメントサービス中で加盟店様を識別するID
	 */
	private $shopId;

	/**
	 * @var string ショップIDと対になるパスワード
	 */
	private $shopPass;

	/**
	 * @var string 取引ID。GMO-PGが払い出した、取引を特定するID
	 */
	private $accessId;

	/**
	 * @var string 取引パスワード。取引IDと対になるパスワード
	 */
	private $accessPass;

	/**
	 * @var string オーダーID。加盟店様が発番した、取引を表すID
	 */
	private $orderId;

	/**
	 * @var string 商品名
	 */
	private $itemName;

	/**
	 * @var string 氏名
	 */
	private $customerName;

	/**
	 * @var string メールアドレス
	 */
	private $mailAddress;

	/**
	 * @var string 加盟店メールアドレス
	 */
	private $shopMailAddress;

	/**
	 * @var string 支払期限
	 */
	private $paymentTermDay;

	/**
	 * @var string リダイレクトURL
	 */
	private $redirectURL;

	/**
	 * @var string 加盟店自由項目1
	 */
	private $clientField1;

	/**
	 * @var string 加盟店自由項目
	 */
	private $clientField2;

	/**
	 * @var string 加盟店自由項目3
	 */
	private $clientField3;

	/**
	 * @var string 加盟店自由項目返却フラグ
	 */
	private $clientFieldFlag;

	/**
	 * コンストラクタ
	 * @param array $params 入力パラメタ
	 * @return unknown_type
	 */
	public function __construct($params = null) {
		parent::__construct($params);
	}

	/**
	 * デフォルト値を設定する
	 */
	public function setDefaultValues() {
		// 加盟店自由項目返却フラグ(固定値)
		$this->clientFieldFlag = "1";
	}

	/**
	 * 入力パラメータ群の値を設定する
	 *
	 * @param IgnoreCaseMap $params 入力パラメータ
	 */
	public function setInputValues($params) {
		if (is_null($params)) {
			return;
		}

		$this->setShopId($this->getStringValue($params, 'ShopID', $this->getShopId()));
		$this->setShopPass($this->getStringValue($params, 'ShopPass', $this->getShopPass()));
		$this->setAccessId($this->getStringValue($params, 'AccessID', $this->getAccessId()));
		$this->setAccessPass($this->getStringValue($params, 'AccessPass', $this->getAccessPass()));
		$this->setOrderId($this->getStringValue($params, 'OrderID', $this->getOrderId()));
		$this->setItemName($this->getStringValue($params, 'ItemName', $this->getItemName()));
		$this->setCustomerName($this->getStringValue($params, 'CustomerName', $this->getCustomerName()));
		$this->setMailAddress($this->getStringValue($params, 'MailAddress', $this->getMailAddress()));
		$this->setShopMailAddress($this->getStringValue($params, 'ShopMailAddress', $this->getShopMailAddress()));
		$this->setPaymentTermDay($this->getIntegerValue($params, 'PaymentTermDay', $this->getPaymentTermDay()));
		$this->setRedirectURL($this->getStringValue($params, 'RedirectURL', $this->getRedirectURL()));
		$this->setClientField1($this->getStringValue($params, 'ClientField1', $this->getClientField1()));
		$this->setClientField2($this->getStringValue($params, 'ClientField2', $this->getClientField2()));
		$this->setClientField3($this->getStringValue($params, 'ClientField3', $this->getClientField3()));
	}

	/**
	 * 文字列表現
	 * URLのパラメータ文字列の形式の文字列を生成する
	 * @return string 接続文字列表現
	 */
	public function toString() {
		$str  = 'ShopID=' . $this->encodeStr($this->getShopId());
		$str .= '&';
		$str .= 'ShopPass=' . $this->encodeStr($this->getShopPass());
		$str .= '&';
		$str .= 'AccessID=' . $this->encodeStr($this->getAccessId());
		$str .= '&';
		$str .= 'AccessPass=' . $this->encodeStr($this->getAccessPass());
		$str .= '&';
		$str .= 'OrderID=' . $this->encodeStr($this->getOrderId());
		$str .= '&';
		$str .= 'ItemName=' . $this->encodeStr($this->getItemName());
		$str .= '&';
		$str .= 'CustomerName=' . $this->encodeStr($this->getCustomerName());
		$str .= '&';

		$str .= 'MailAddress=' . $this->encodeStr($this->getMailAddress());
		$str .= '&';

		$str .= 'ShopMailAddress=' . $this->encodeStr($this->getShopMailAddress());
		$str .= '&';

		$str .= 'PaymentTermDay=' . $this->encodeStr($this->getPaymentTermDay());
		$str .= '&';

		$str .= 'RedirectURL=' . $this->encodeStr($this->getRedirectURL());
		$str .= '&';
		$str .= 'ClientField1=' . $this->encodeStr($this->getClientField1());
		$str .= '&';
		$str .= 'ClientField2=' . $this->encodeStr($this->getClientField2());
		$str .= '&';
		$str .= 'ClientField3=' . $this->encodeStr($this->getClientField3());
		$str .= '&';
		$str .= 'ClientFieldFlag=' . $this->clientFieldFlag;

		return $str;
	}

	/**
	 * ショップId取得
	 * @return string ショップId
	 */
	public function getShopId(){
		return $this->shopId;
	}

	/**
	 * ショップパスワードの取得
	 * @return string ショップパスワード
	 */
	public function getShopPass(){
		return $this->shopPass;
	}

	/**
	 * 取引ID取得
	 * @return string 取引ID
	 */
	public function getAccessId() {
		return $this->accessId;
	}

	/**
	 * 取引パスワード取得
	 * @return string 取引パスワード
	 */
	public function getAccessPass() {
		return $this->accessPass;
	}

	/**
	 * オーダーID取得
	 * @return string オーダーID
	 */
	public function getOrderId() {
		return $this->orderId;
	}

	/**
	 * リダイレクトURL取得
	 * @return string リダイレクトURL
	 */
	public function getRedirectURL(){
		return $this->redirectURL;
	}

	/**
	 * 商品名取得
	 * @return string 商品名
	 */
	public function getItemName(){
		return $this->itemName;
	}

	/**
	 * 氏名取得
	 * @return string 氏名
	 */
	public function getCustomerName(){
		return $this->customerName;
	}

	/**
	 * メールアドレス取得
	 * @return string メールアドレス
	 */
	public function getMailAddress(){
		return $this->mailAddress;
	}

	/**
	 * 加盟店メールアドレス取得
	 * @return string 加盟店メールアドレス
	 */
	public function getShopMailAddress(){
		return $this->shopMailAddress;
	}

	/**
	 * 支払期限日数取得
	 * @return string 支払期限日数
	 */
	public function getPaymentTermDay(){
		return $this->paymentTermDay;
	}

	/**
	 * 加盟店自由項目1取得
	 * @return string 加盟店自由項目1
	 */
	public function getClientField1() {
		return $this->clientField1;
	}

	/**
	 * 加盟店自由項目2取得
	 * @return string 加盟店自由項目2
	 */
	public function getClientField2() {
		return $this->clientField2;
	}

	/**
	 * 加盟店自由項目3取得
	 * @return string 加盟店自由項目3
	 */
	public function getClientField3() {
		return $this->clientField3;
	}

	/**
	 * ショップIdの設定
	 * @param $shopId ショップId
	 */
	public function setShopId( $shopId ){
		$this->shopId = $shopId;
	}

	/**
	 * ショップパスワードの設定
	 * @param $shopPass ショップパスワード
	 */
	public function setShopPass( $shopPass ){
		$this->shopPass = $shopPass;
	}

	/**
	 * 取引ID設定
	 *
	 * @param string $accessId 取引ID
	 */
	public function setAccessId($accessId) {
		$this->accessId = $accessId;
	}

	/**
	 * 取引パスワードを設定
	 *
	 * @param string $accessPass 取引パスワード
	 */
	public function setAccessPass($accessPass) {
		$this->accessPass = $accessPass;
	}

	/**
	 * オーダーID設定
	 *
	 * @param string $orderId オーダーID
	 */
	public function setOrderId($orderId) {
		$this->orderId = $orderId;
	}

	/**
	 * 商品名設定
	 * @param string $itemName 商品名
	 */
	public function setItemName( $itemName ){
		$this->itemName = $itemName;
	}

	/**
	 * 氏名設定
	 * @param string $customerName 氏名
	 */
	public function setCustomerName( $customerName ){
		$this->customerName = $customerName;
	}

	/**
	 * メールアドレス設定
	 * @param string $mailAddress メールアドレス
	 */
	public function setMailAddress( $mailAddress ){
		$this->mailAddress = $mailAddress;
	}

	/**
	 * 加盟店メールアドレス設定
	 * @param string $shopMailAddress 加盟店メールアドレス
	 */
	public function setShopMailAddress( $shopMailAddress ){
		$this->shopMailAddress = $shopMailAddress;
	}

	/**
	 * 支払期限日数設定
	 * @param string $paymentTermDay 支払期限日数
	 */
	public function setPaymentTermDay( $paymentTermDay ){
		$this->paymentTermDay = $paymentTermDay;
	}

	/**
	 * リダイレクトURL設定
	 * @param string $redirectURL リダイレクトURL
	 */
	public function setRedirectURL( $redirectURL ){
		$this->redirectURL = $redirectURL;
	}

	/**
	 * 加盟店自由項目1設定
	 *
	 * @param string $clientField1 加盟店自由項目1
	 */
	public function setClientField1($clientField1) {
		$this->clientField1 = $clientField1;
	}

	/**
	 * 加盟店自由項目2設定
	 *
	 * @param string $clientField2 加盟店自由項目2
	 */
	public function setClientField2($clientField2) {
		$this->clientField2 = $clientField2;
	}

	/**
	 * 加盟店自由項目3設定
	 *
	 * @param string $clientField3 加盟店自由項目3
	 */
	public function setClientField3($clientField3) {
		$this->clientField3 = $clientField3;
	}
}
