<?php
require_once ('com/gmo_pg/client/output/BaseOutput.php');
/**
 * <b>自動売上プラン変更　出力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage output
 * @see outputPackageInfo.php
 * @author GMO PaymentGateway
 */
class ChangeRecurringPlanOutput extends BaseOutput {

	/**
	 * @var string ショップID
	 */
	private $shopID;
	/**
	 * @var string プランID
	 */
	private $planID;
	/**
	 * @var string プラン名
	 */
	private $planName;
	/**
	 * @var string プラン説明
	 */
	private $description;
	/**
	 * @var string 課金手段
	 */
	private $method;
	/**
	 * @var integer 利用金額
	 */
	private $amount;
	/**
	 * @var integer 税送料
	 */
	private $tax;
	/**
	 * @var string 課金月
	 */
	private $chargeMonth;
	/**
	 * @var string 課金基準日 1～31
	 */
	private $chargeDay;


	/**
	 * コンストラクタ
	 *
	 * @param IgnoreCaseMap $params  出力パラメータ
	 */
	public function __construct($params = null) {
		parent::__construct($params);

		// 引数が無い場合は戻る
		if (is_null($params)) {
            return;
        }

        // マップの展開
		$this->setShopID($params->get('ShopID'));
		$this->setPlanID($params->get('PlanID'));
		$this->setPlanName($params->get('PlanName'));
		$this->setDescription($params->get('Description'));
		$this->setMethod($params->get('Method'));
		$this->setAmount($params->get('Amount'));
		$this->setTax($params->get('Tax'));
		$this->setChargeMonth($params->get('ChargeMonth'));
		$this->setChargeDay($params->get('ChargeDay'));

	}

	/**
	 * ショップID取得
	 * @return string ショップID
	 */
	public function getShopID() {
		return $this->shopID;
	}
	/**
	 * プランID取得
	 * @return string プランID
	 */
	public function getPlanID() {
		return $this->planID;
	}
	/**
	 * プラン名取得
	 * @return string プラン名
	 */
	public function getPlanName() {
		return $this->planName;
	}
	/**
	 * プラン説明取得
	 * @return string プラン説明
	 */
	public function getDescription() {
		return $this->description;
	}
	/**
	 * 課金手段取得
	 * @return string 課金手段
	 */
	public function getMethod() {
		return $this->method;
	}
	/**
	 * 利用金額取得
	 * @return integer 利用金額
	 */
	public function getAmount() {
		return $this->amount;
	}
	/**
	 * 税送料取得
	 * @return integer 税送料
	 */
	public function getTax() {
		return $this->tax;
	}
	/**
	 * 課金月取得
	 * @return string 課金月
	 */
	public function getChargeMonth() {
		return $this->chargeMonth;
	}
	/**
	 * 課金基準日 1～31取得
	 * @return string 課金基準日 1～31
	 */
	public function getChargeDay() {
		return $this->chargeDay;
	}

	/**
	 * ショップID設定
	 *
	 * @param string $shopID
	 */
	public function setShopID($shopID) {
		$this->shopID = $shopID;
	}
	/**
	 * プランID設定
	 *
	 * @param string $planID
	 */
	public function setPlanID($planID) {
		$this->planID = $planID;
	}
	/**
	 * プラン名設定
	 *
	 * @param string $planName
	 */
	public function setPlanName($planName) {
		$this->planName = $planName;
	}
	/**
	 * プラン説明設定
	 *
	 * @param string $description
	 */
	public function setDescription($description) {
		$this->description = $description;
	}
	/**
	 * 課金手段設定
	 *
	 * @param string $method
	 */
	public function setMethod($method) {
		$this->method = $method;
	}
	/**
	 * 利用金額設定
	 *
	 * @param integer $amount
	 */
	public function setAmount($amount) {
		$this->amount = $amount;
	}
	/**
	 * 税送料設定
	 *
	 * @param integer $tax
	 */
	public function setTax($tax) {
		$this->tax = $tax;
	}
	/**
	 * 課金月設定
	 *
	 * @param string $chargeMonth
	 */
	public function setChargeMonth($chargeMonth) {
		$this->chargeMonth = $chargeMonth;
	}
	/**
	 * 課金基準日 1～31設定
	 *
	 * @param string $chargeDay
	 */
	public function setChargeDay($chargeDay) {
		$this->chargeDay = $chargeDay;
	}

	/**
	 * 文字列表現
	 * <p>
	 *  現在の各パラメータを、パラメータ名=値&パラメータ名=値の形式で取得します。
	 * </p>
	 * @return string 出力パラメータの文字列表現
	 */
	public function toString() {
		$str ='';
		$str .= 'ShopID=' . $this->encodeStr($this->getShopID());
		$str .='&';
		$str .= 'PlanID=' . $this->encodeStr($this->getPlanID());
		$str .='&';
		$str .= 'PlanName=' . $this->encodeStr($this->getPlanName());
		$str .='&';
		$str .= 'Description=' . $this->encodeStr($this->getDescription());
		$str .='&';
		$str .= 'Method=' . $this->encodeStr($this->getMethod());
		$str .='&';
		$str .= 'Amount=' . $this->encodeStr($this->getAmount());
		$str .='&';
		$str .= 'Tax=' . $this->encodeStr($this->getTax());
		$str .='&';
		$str .= 'ChargeMonth=' . $this->encodeStr($this->getChargeMonth());
		$str .='&';
		$str .= 'ChargeDay=' . $this->encodeStr($this->getChargeDay());


	    if ($this->isErrorOccurred()) {
            // エラー文字列を連結して返す
            $errString = parent::toString();
            $str .= '&' . $errString;
        }

        return $str;
	}

}
?>
