<?php
require_once ('com/gmo_pg/client/output/BaseOutput.php');
/**
 * <b>多通貨クレジット決済（DCC)金額変更　出力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage output
 * @see outputPackageInfo.php
 * @author GMO PaymentGateway
 */
class ChangeTranDccOutput extends BaseOutput {

	/**
	 * @var string ACS呼出判定
	 */
	private $aCS;
	/**
	 * @var string ACS認証ページURL
	 */
	private $aCSUrl;
	/**
	 * @var string 3DS要求電文
	 */
	private $paReq;
	/**
	 * @var string 取引ID
	 */
	private $mD;
	/**
	 * @var string オーダーID
	 */
	private $orderID;
	/**
	 * @var string 支払方法
	 */
	private $method;
	/**
	 * @var string 支払通貨コード
	 */
	private $dccCurrency;
	/**
	 * @var bigDecimal 支払通貨決済額(金額変更後)
	 */
	private $dccAmount;
	/**
	 * @var bigDecimal 為替レート(金額変更後)
	 */
	private $dccRate;
	/**
	 * @var string FX追跡番号(FTN)
	 */
	private $ftn;
	/**
	 * @var string 加盟店自由項目1
	 */
	private $clientField1;
	/**
	 * @var string 加盟店自由項目2
	 */
	private $clientField2;
	/**
	 * @var string 加盟店自由項目3
	 */
	private $clientField3;
	/**
	 * @var string ActiveServerへのリダイレクトURL
	 */
	private $redirectUrl;


	/**
	 * コンストラクタ
	 *
	 * @param IgnoreCaseMap $params  出力パラメータ
	 */
	public function __construct($params = null) {
		parent::__construct($params);

		// 引数が無い場合は戻る
		if (is_null($params)) {
            return;
        }

        // マップの展開
		$this->setACS($params->get('ACS'));
		$this->setACSUrl($params->get('ACSUrl'));
		$this->setPaReq($params->get('PaReq'));
		$this->setMD($params->get('MD'));
		$this->setOrderID($params->get('OrderID'));
		$this->setMethod($params->get('Method'));
		$this->setDccCurrency($params->get('DccCurrency'));
		$this->setDccAmount($params->get('DccAmount'));
		$this->setDccRate($params->get('DccRate'));
		$this->setFtn($params->get('Ftn'));
		$this->setClientField1($params->get('ClientField1'));
		$this->setClientField2($params->get('ClientField2'));
		$this->setClientField3($params->get('ClientField3'));
		$this->setRedirectUrl($params->get('RedirectUrl'));

	}

	/**
	 * ACS呼出判定取得
	 * @return string ACS呼出判定
	 */
	public function getACS() {
		return $this->aCS;
	}
	/**
	 * ACS認証ページURL取得
	 * @return string ACS認証ページURL
	 */
	public function getACSUrl() {
		return $this->aCSUrl;
	}
	/**
	 * 3DS要求電文取得
	 * @return string 3DS要求電文
	 */
	public function getPaReq() {
		return $this->paReq;
	}
	/**
	 * 取引ID取得
	 * @return string 取引ID
	 */
	public function getMD() {
		return $this->mD;
	}
	/**
	 * オーダーID取得
	 * @return string オーダーID
	 */
	public function getOrderID() {
		return $this->orderID;
	}
	/**
	 * 支払方法取得
	 * @return string 支払方法
	 */
	public function getMethod() {
		return $this->method;
	}
	/**
	 * 支払通貨コード取得
	 * @return string 支払通貨コード
	 */
	public function getDccCurrency() {
		return $this->dccCurrency;
	}
	/**
	 * 支払通貨決済額(金額変更後)取得
	 * @return bigDecimal 支払通貨決済額(金額変更後)
	 */
	public function getDccAmount() {
		return $this->dccAmount;
	}
	/**
	 * 為替レート(金額変更後)取得
	 * @return bigDecimal 為替レート(金額変更後)
	 */
	public function getDccRate() {
		return $this->dccRate;
	}
	/**
	 * FX追跡番号(FTN)取得
	 * @return string FX追跡番号(FTN)
	 */
	public function getFtn() {
		return $this->ftn;
	}
	/**
	 * 加盟店自由項目1取得
	 * @return string 加盟店自由項目1
	 */
	public function getClientField1() {
		return $this->clientField1;
	}
	/**
	 * 加盟店自由項目2取得
	 * @return string 加盟店自由項目2
	 */
	public function getClientField2() {
		return $this->clientField2;
	}
	/**
	 * 加盟店自由項目3取得
	 * @return string 加盟店自由項目3
	 */
	public function getClientField3() {
		return $this->clientField3;
	}
	/**
	 * ActiveServerへのリダイレクトURL取得
	 * @return string ActiveServerへのリダイレクトURL
	 */
	public function getRedirectUrl() {
	    return $this->redirectUrl;
	}

	/**
	 * ACS呼出判定設定
	 *
	 * @param string $aCS
	 */
	public function setACS($aCS) {
		$this->aCS = $aCS;
	}
	/**
	 * ACS認証ページURL設定
	 *
	 * @param string $aCSUrl
	 */
	public function setACSUrl($aCSUrl) {
		$this->aCSUrl = $aCSUrl;
	}
	/**
	 * 3DS要求電文設定
	 *
	 * @param string $paReq
	 */
	public function setPaReq($paReq) {
		$this->paReq = $paReq;
	}
	/**
	 * 取引ID設定
	 *
	 * @param string $mD
	 */
	public function setMD($mD) {
		$this->mD = $mD;
	}
	/**
	 * オーダーID設定
	 *
	 * @param string $orderID
	 */
	public function setOrderID($orderID) {
		$this->orderID = $orderID;
	}
	/**
	 * 支払方法設定
	 *
	 * @param string $method
	 */
	public function setMethod($method) {
		$this->method = $method;
	}
	/**
	 * 支払通貨コード設定
	 *
	 * @param string $dccCurrency
	 */
	public function setDccCurrency($dccCurrency) {
		$this->dccCurrency = $dccCurrency;
	}
	/**
	 * 支払通貨決済額(金額変更後)設定
	 *
	 * @param bigDecimal $dccAmount
	 */
	public function setDccAmount($dccAmount) {
		$this->dccAmount = $dccAmount;
	}
	/**
	 * 為替レート(金額変更後)設定
	 *
	 * @param bigDecimal $dccRate
	 */
	public function setDccRate($dccRate) {
		$this->dccRate = $dccRate;
	}
	/**
	 * FX追跡番号(FTN)設定
	 *
	 * @param string $ftn
	 */
	public function setFtn($ftn) {
		$this->ftn = $ftn;
	}
	/**
	 * 加盟店自由項目1設定
	 *
	 * @param string $clientField1
	 */
	public function setClientField1($clientField1) {
		$this->clientField1 = $clientField1;
	}
	/**
	 * 加盟店自由項目2設定
	 *
	 * @param string $clientField2
	 */
	public function setClientField2($clientField2) {
		$this->clientField2 = $clientField2;
	}
	/**
	 * 加盟店自由項目3設定
	 *
	 * @param string $clientField3
	 */
	public function setClientField3($clientField3) {
		$this->clientField3 = $clientField3;
	}
	/**
	 * ActiveServerへのリダイレクトURL設定
	 * @param string $id トランザクションID
	 */
	public function setRedirectUrl( $redirectUrl ) {
	    $this->redirectUrl = $redirectUrl;
	}

	/**
	 * 文字列表現
	 * <p>
	 *  現在の各パラメータを、パラメータ名=値&パラメータ名=値の形式で取得します。
	 * </p>
	 * @return string 出力パラメータの文字列表現
	 */
	public function toString() {
		$str ='';
		$str .= 'ACS=' . $this->encodeStr($this->getACS());
		$str .='&';
		$str .= 'ACSUrl=' . $this->encodeStr($this->getACSUrl());
		$str .='&';
		$str .= 'PaReq=' . $this->encodeStr($this->getPaReq());
		$str .='&';
		$str .= 'MD=' . $this->encodeStr($this->getMD());
		$str .='&';
		$str .= 'OrderID=' . $this->encodeStr($this->getOrderID());
		$str .='&';
		$str .= 'Method=' . $this->encodeStr($this->getMethod());
		$str .='&';
		$str .= 'DccCurrency=' . $this->encodeStr($this->getDccCurrency());
		$str .='&';
		$str .= 'DccAmount=' . $this->encodeStr($this->getDccAmount());
		$str .='&';
		$str .= 'DccRate=' . $this->encodeStr($this->getDccRate());
		$str .='&';
		$str .= 'Ftn=' . $this->encodeStr($this->getFtn());
		$str .='&';
		$str .= 'ClientField1=' . $this->encodeStr($this->getClientField1());
		$str .='&';
		$str .= 'ClientField2=' . $this->encodeStr($this->getClientField2());
		$str .='&';
		$str .= 'ClientField3=' . $this->encodeStr($this->getClientField3());
		$str .= '&';
		$str .= 'RedirectUrl=' . $this->getRedirectUrl();


	    if ($this->isErrorOccurred()) {
            // エラー文字列を連結して返す
            $errString = parent::toString();
            $str .= '&' . $errString;
        }

        return $str;
	}

}
?>
