<?php
require_once 'com/gmo_pg/client/output/EntryTranBankDirectOutput.php';
require_once 'com/gmo_pg/client/output/ExecTranBankDirectOutput.php';
/**
 * <b>口座直結決済登録・決済一括実行  出力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage output
 * @see outputPackageInfo.php
 * @author GMO PaymentGateway
 */
class EntryExecTranBankDirectOutput {

	/**
	 * @var EntryTranBankDirectOutput 口座直結決済登録出力パラメータ
	 */
	private $entryTranBankDirectOutput;/*@var $entryTranBankDirectOutput EntryTranBankDirectOutput */

	/**
	 * @var ExecTranBankDirectOutput 口座直結決済実行出力パラメータ
	 */
	private $execTranBankDirectOutput;/*@var $execTranBankDirectOutput ExecTranBankDirectOutput */

	/**
	 * コンストラクタ
	 *
	 * @param IgnoreCaseMap $params    入力パラメータ
	 */
	public function __construct($params = null) {
		$this->entryTranBankDirectOutput = new EntryTranBankDirectOutput($params);
		$this->execTranBankDirectOutput = new ExecTranBankDirectOutput($params);
	}

	/**
	 * 口座直結決済登録出力パラメータ取得
	 * @return EntryTranBankDirectOutput 口座直結決済登録出力パラメータ
	 */
	public function &getEntryTranBankDirectOutput() {
		return $this->entryTranBankDirectOutput;
	}

	/**
	 * 口座直結決済実行出力パラメータ取得
	 * @return ExecTranBankDirectOutput 口座直結決済実行出力パラメータ
	 */
	public function &getExecTranBankDirectOutput() {
		return $this->execTranBankDirectOutput;
	}

	/**
	 * 口座直結決済登録出力パラメータ設定
	 *
	 * @param EntryTranBankDirectOutput  $entryTranBankDirectOutput 口座直結決済登録出力パラメータ
	 */
	public function setEntryTranBankDirectOutput(&$entryTranBankDirectOutput) {
		$this->entryTranBankDirectOutput = $entryTranBankDirectOutput;
	}

	/**
	 * 口座直結決済決済実行出力パラメータ設定
	 *
	 * @param ExecTranBankDirectOutput $execTranBankDirectOutput 口座直結決済実行出力パラメータ
	 */
	public function setExecTranBankDirectOutput(&$execTranBankDirectOutput) {
		$this->execTranBankDirectOutput = $execTranBankDirectOutput;
	}

	/**
	 * 取引ID取得
	 * @return string 取引ID
	 */
	public function getAccessID() {
		return $this->entryTranBankDirectOutput->getAccessID();

	}
	/**
	 * 取引パスワード取得
	 * @return string 取引パスワード
	 */
	public function getAccessPass() {
		return $this->entryTranBankDirectOutput->getAccessPass();

	}
	/**
	 * オーダーID取得
	 * @return string オーダーID
	 */
	public function getOrderID() {
		return $this->execTranBankDirectOutput->getOrderID();

	}
	/**
	 * 現状態取得
	 * @return string 現状態
	 */
	public function getStatus() {
		return $this->execTranBankDirectOutput->getStatus();

	}
	/**
	 * 決済日付取得
	 * @return string 決済日付
	 */
	public function getTranDate() {
		return $this->execTranBankDirectOutput->getTranDate();

	}
	/**
	 * 改ざんチェック文字列取得
	 * @return string 改ざんチェック文字列
	 */
	public function getCheckString() {
		return $this->execTranBankDirectOutput->getCheckString();

	}

	/**
	 * 取引ID設定
	 *
	 * @param string $accessID
	 */
	public function setAccessID($accessID) {
		$this->entryTranBankDirectOutput->setAccessID($accessID);

	}
	/**
	 * 取引パスワード設定
	 *
	 * @param string $accessPass
	 */
	public function setAccessPass($accessPass) {
		$this->entryTranBankDirectOutput->setAccessPass($accessPass);

	}
	/**
	 * オーダーID設定
	 *
	 * @param string $orderID
	 */
	public function setOrderID($orderID) {
		$this->execTranBankDirectOutput->setOrderID($orderID);

	}
	/**
	 * 現状態設定
	 *
	 * @param string $status
	 */
	public function setStatus($status) {
		$this->execTranBankDirectOutput->setStatus($status);

	}
	/**
	 * 決済日付設定
	 *
	 * @param string $tranDate
	 */
	public function setTranDate($tranDate) {
		$this->execTranBankDirectOutput->setTranDate($tranDate);

	}
	/**
	 * 改ざんチェック文字列設定
	 *
	 * @param string $checkString
	 */
	public function setCheckString($checkString) {
		$this->execTranBankDirectOutput->setCheckString($checkString);

	}

	/**
	 * 取引登録エラーリスト取得
	 * @return  array エラーリスト
	 */
	public function &getEntryErrList() {
		return $this->entryTranBankDirectOutput->getErrList();
	}

	/**
	 * 決済実行エラーリスト取得
	 * @return array エラーリスト
	 */
	public function &getExecErrList() {
		return $this->execTranBankDirectOutput->getErrList();
	}

	/**
	 * 取引登録エラー発生判定
	 * @return boolean 取引登録時エラー有無(true=エラー発生)
	 */
	public function isEntryErrorOccurred() {
		$entryErrList =& $this->entryTranBankDirectOutput->getErrList();
		return 0 < count($entryErrList);
	}

	/**
	 * 決済実行エラー発生判定
	 * @return boolean 決済実行時エラー有無(true=エラー発生)
	 */
	public function isExecErrorOccurred() {
		$execErrList =& $this->execTranBankDirectOutput->getErrList();
		return 0 < count($execErrList);
	}

	/**
	 * エラー発生判定
	 * @return boolean エラー発生有無(true=エラー発生)
	 */
	public function isErrorOccurred() {
		return $this->isEntryErrorOccurred() || $this->isExecErrorOccurred();
	}

}
?>
