<?php
require_once ('com/gmo_pg/client/output/BaseOutput.php');
/**
 * <b>利用可能金融機関照会　出力パラメータクラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage output
 * @see outputPackageInfo.php
 * @author GMO PaymentGateway
 * @version 1.0
 * @created 01-01-2008 00:00:00
 */
class SearchAvailableBankDirectOutput extends BaseOutput {

	/**
	 * @var array  金融機関コード配列 金融機関コードを要素にもつ一次元配列
	 */
	private $bankCode;


	/**
	 * @var array 利用可能金融機関コードの配列。利用可能金融機関コード情報の連想配列が繰り返される、二次元配列。例：
	 *
	 *	<code>
	 *	$availableBankCodeList =
	 * 		array(
	 *			array(
	 *				'BankCode' =>	0001 ,
	 *			),
	 *			array(
	 *				'BankCode' =>	0002 ,
	 *			),
	 *  	)
	 * </code>
	 */
	private $bankCodeList = null;


	/**
	 * コンストラクタ
	 *
	 * @param IgnoreCaseMap $params  出力パラメータ
	 */
	public function __construct($params = null) {
		parent::__construct($params);

		// 引数が無い場合は戻る
		if (is_null($params)) {
            return;
        }

        // マップの展開
        //金融機関コードは複数返るので、全てマップに展開
        $bankCodeArray = null;
        $tmp =  $params->get('BankCode');
        $bankCode = $params->get('BankCode');


        if( is_null( $bankCode ) ){
        	return;
        }
        //配列として設定
        if( !is_null( $bankCode ) ){
        	$this->setBankCode(	explode('|'	,$bankCode ) );
        }

        //金融機関コード配列を作成
        $bankCodeList = null;
        $count = count( $this->bankCode );
        for( $i = 0 ; $i < $count; $i++ ){
        	$tmp = null;
        	$tmp['BankCode']		=	$this->bankCode[$i];

        	$bankCodeList[]	=	$tmp;
        }
        $this->bankCodeList = $bankCodeList;
	}

	/**
	 * 金融機関コード配列の配列取得
	 * @return array 金融機関コード
	 */
	public function getBankCode() {
	    return $this->bankCode;
	}

	/**
	 * 金融機関コードリスト取得
	 * <p>
	 * 	　$bankCodeListを返します
	 * </p>
	 * @return array 金融機関コードリスト
	 */
	public function getBankCodeList() {
	    return $this->bankCodeList;
	}

	/**
	 * 金融機関コード設定
	 * @param array $bankCode 金融機関コード
	 */
	public function setBankCode( $bankCode) {
	    $this->bankCode =$bankCode ;
	}

	/**
	 * 金融機関コードリスト設定
	 * @param array $bankCodeList 金融機関コードリスト設定
	 */
	public function setBankCodeList($bankCodeList) {
	    $this->bankCodeList = $bankCodeList;
	}

	/**
	 * 文字列表現
	 * <p>
	 *  現在の各パラメータを、パラメータ名=値&パラメータ名=値の形式で取得します。
	 * </p>
	 * @return string 出力パラメータの文字列表現
	 */
	public function toString() {
	    $str  = 'BankCode='		.	(is_null($this->bankCode)? '' : implode('|',$this->bankCode));

	    if ($this->isErrorOccurred()) {
	        // エラー文字列を連結して返す
	        $errString = parent::toString();
	        $str .= '&' . $errString;
	    }

	    return $str;
	}
}
?>