<?php
require_once 'com/gmo_pg/client/output/EntryExecTranAupayAppAcceptOutput.php';
require_once 'com/gmo_pg/client/tran/EntryTranAupayAppAccept.php';
require_once 'com/gmo_pg/client/tran/ExecTranAupayAppAccept.php';
/**
 * <b>au PAY（アプリ方式）（随時決済承諾）登録・決済一括実行　実行クラス</b>
 *
 * @package com.gmo_pg.client
 * @subpackage tran
 * @see tranPackageInfo.php
 * @author GMO PaymentGateway
 */
class EntryExecTranAupayAppAccept {
	/**
	 * @var Gmopg_Log ログ
	 */
	private $log;

	/**
	 * @var GPayException 例外
	 */
	private $exception;

	/**
	 * コンストラクタ
	 */
	public function __construct() {
		$this->log = new Gmopg_Log(get_class($this));
	}

	/**
	 * 例外の発生を判定する
	 *
	 * @param mixed $target    判定対象
	 */
	private function errorTrap(&$target) {
		if (is_null($target->getException())) {
			return false;
		}
		$this->exception = $target->getException();
		return true;
	}

	/**
	 * 例外の発生を判定する
	 *
	 * @return  boolean 判定結果(true=エラーアリ)
	 */
	public function isExceptionOccured() {
		return false == is_null($this->exception);
	}

	/**
	 * 例外を返す
	 *
	 * @return  GPayException 例外
	 */
	public function &getException() {
		return $this->exception;
	}

	/**
	 * au PAY（アプリ方式）（随時決済承諾）登録・決済を実行する
	 *
	 * @param EntryExecTranAupayAppAcceptInput $input    au PAY（アプリ方式）（随時決済承諾）登録・決済入力パラメータ
	 * @return  EntryExecTranAupayAppAcceptOutput au PAY（アプリ方式）（随時決済承諾）登録・決済出力パラメータ
	 * @exception GPayException
	 */
	public function exec(&$input) {
		// au PAY（アプリ方式）（随時決済承諾）取引登録入力パラメータを取得
		$entryTranAupayAppAcceptInput =& $input->getEntryTranAupayAppAcceptInput();
		// au PAY（アプリ方式）（随時決済承諾）決済実行入力パラメータを取得
		$execTranAupayAppAcceptInput =& $input->getExecTranAupayAppAcceptInput();

		// au PAY（アプリ方式）（随時決済承諾）登録・決済出力パラメータを生成
		$output = new EntryExecTranAupayAppAcceptOutput();

		// 取引ID、取引パスワードを取得
		$accessId = $execTranAupayAppAcceptInput->getAccessId();
		$accessPass = $execTranAupayAppAcceptInput->getAccessPass();

		// 取引ID、取引パスワードが設定されていないとき
		if (is_null($accessId) || 0 == strlen($accessId) || is_null($accessPass)) {
			// au PAY（アプリ方式）（随時決済承諾）取引登録を実行
			$this->log->debug("au PAY（アプリ方式）（随時決済承諾）取引登録実行");
			$entryTranAupayAppAccept = new EntryTranAupayAppAccept();
			$entryTranAupayAppAcceptOutput = $entryTranAupayAppAccept->exec($entryTranAupayAppAcceptInput);

			if ($this->errorTrap($entryTranAupayAppAccept)) {
				return $output;
			}

			// 取引ID、取引パスワードを決済実行用のパラメータに設定
			$accessId = $entryTranAupayAppAcceptOutput->getAccessId();
			$accessPass = $entryTranAupayAppAcceptOutput->getAccessPass();
			$execTranAupayAppAcceptInput->setAccessId($accessId);
			$execTranAupayAppAcceptInput->setAccessPass($accessPass);

			$output->setEntryTranAupayAppAcceptOutput($entryTranAupayAppAcceptOutput);
		}

		$this->log->debug("取引ID : [$accessId]  取引パスワード : [$accessPass]");

		// 取引登録でエラーが起きたとき決済を実行せずに戻る
		if ($output->isEntryErrorOccurred()) {
			$this->log->debug("<<<取引登録失敗>>>");
			return $output;
		}

		// 決済実行
		$this->log->debug("決済実行");
		$execTranAupayAppAccept = new ExecTranAupayAppAccept();
		$execTranAupayAppAcceptOutput = $execTranAupayAppAccept->exec($execTranAupayAppAcceptInput);

		$output->setExecTranAupayAppAcceptOutput($execTranAupayAppAcceptOutput);

		$this->errorTrap($execTranAupayAppAccept);

		return $output;
	}


}
?>
